import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, arc, pie, scaleBand, scaleLinear, max } from 'd3';

const width = 960;
const height = 500;
const margin = {top: 20, right: 20, bottom: 20, left: 200};
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;

const csvUrl =
  'https://gist.githubusercontent.com/fu160/f08f61b78466d9a16cd1bd49297f72f6/raw/7cbce871beefc55b6ba6ef088fb3d063b034cd0b/worldPopulation.csv';

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
     const row = d=> {
        d.Population = +d['2020']/1000000;
        return d;
      }
    csv(csvUrl,row).then((data) => {
      console.log("fetch");
     
     
     
      
      data.sort((a, b) => b.Population - a.Population);
      let temp = data.slice(0,9);
      
      setData(temp);
    });
  }, []);

  console.log(data);
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const yScale = scaleBand()
  .domain(data.map(d=>d.Country))
  .range([0, innerHeight])
  
  const xScale = scaleLinear()  
  .domain([0, max(data, d=>d.Population)])
  .range([0, innerWidth])
  
  console.log(xScale.ticks());
  
  return (
    <svg width={width} height={height}>
    
      <g transform = {`translate(${margin.left},${margin.top})`}>
        
          {xScale.ticks().map(tickValue=>(
            <g key={tickValue} transform={`translate(${xScale(tickValue)}, 0)`}>
              <line y2={innerHeight} stroke="black"/>
              <text dy="0.71em" style={{textAnchor: 'middle'}} y={innerHeight+3}>{tickValue}</text>
            </g>
      		))}
         {yScale.domain().map(tickValue=>(
           
              <text key={tickValue} dy="0.32em"
                style={{textAnchor: 'end'}} 
                y={yScale(tickValue)+yScale.bandwidth()/2}
               >{tickValue}</text>
            
          
      		))}
        
      {data.map(d=><rect key={d.Country} x={0} y={yScale(d.Country)} width={xScale(d.Population)} height={yScale.bandwidth()} />)}
      </g>
    </svg>
      
  );
};

const rootElement = document.getElementById(
  'root'
);

ReactDOM.render(<App />, rootElement);
